@@ -1,18 +1,20 @@
 from bs4 import BeautifulSoup
 
-from kraken_extract_from_html.extractors import extract_feeds
-from kraken_extract_from_html.extractors import extract_images
-from kraken_extract_from_html.extractors import extract_links
-from kraken_extract_from_html.extractors import extract_schemas
-from kraken_extract_from_html.extractors import extract_src
-from kraken_extract_from_html.extractors import extract_text
-from kraken_extract_from_html.extractors import extract_title
+from kraken_extract_from_html.extractors.extract_feeds import extract_feeds
+from kraken_extract_from_html.extractors.extract_images import extract_images
+from kraken_extract_from_html.extractors.extract_links import extract_links
+from kraken_extract_from_html.extractors.extract_schemas import extract_schemas
+from kraken_extract_from_html.extractors.extract_src import extract_src
+from kraken_extract_from_html.extractors.extract_text import extract_text
+from kraken_extract_from_html.extractors.extract_title import extract_title
 
 
 
 def get(url, html):
     return process_extraction(url, html)
 
+def kraken_extract_from_html(url, html):
+    return process_extraction(url, html)
 
 
 def process_extraction(url, html, image_urls = None):
